@@ -20,7 +20,7 @@
 
 
 """
-__author__  = 'Christian Heimes <ch@comlounge.net>, Alec Mitchell'
+__author__  = 'Christian Heimes <tiran@cheimes.de>, Alec Mitchell'
 __docformat__ = 'restructuredtext'
 __old_name__ = 'Products.ATContentTypes.types.ATTopic'
 
@@ -29,8 +29,6 @@ from types import TupleType
 from types import StringType
 
 from Products.CMFCore.permissions import View
-from Products.CMFCore.permissions import ModifyPortalContent
-from Products.CMFCore.permissions import ManageProperties
 from Products.CMFCore.utils import getToolByName
 from Products.CMFPlone.CatalogTool import CatalogTool
 from AccessControl import ClassSecurityInfo
@@ -68,7 +66,7 @@ from Products.CMFPlone.PloneBatch import Batch
 
 # A couple of fields just don't make sense to sort (for a user),
 # some are just doubles.
-IGNORED_FIELDS = ['Date', 'allowedRolesAndUsers', 'getId', 'in_reply_to', 
+IGNORED_FIELDS = ['Date', 'allowedRolesAndUsers', 'getId', 'in_reply_to',
     'meta_type',
     # 'portal_type' # portal type and Type might differ!
     ]
@@ -159,7 +157,7 @@ class ATTopic(ATCTFolder):
     archetype_name = 'Smart Folder'
     immediate_view = 'atct_topic_view'
     default_view   = 'atct_topic_view'
-    suppl_views    = ()
+    suppl_views    = ('folder_listing', 'folder_summary_view', 'folder_tabular_view', 'atct_album_view')
     _atct_newTypeFor = {'portal_type' : 'CMF Topic', 'meta_type' : 'Portal Topic'}
     typeDescription= 'An automatically updated stored search that can be used to display items matching criteria you specify.'
     typeDescMsgId  = 'description_edit_topic'
@@ -174,6 +172,9 @@ class ATTopic(ATCTFolder):
 
     __implements__ = ATCTFolder.__implements__, IATTopic
 
+    # Enable marshalling via WebDAV/FTP/ExternalEditor.
+    __dav_marshall__ = True
+
     security       = ClassSecurityInfo()
     actions = updateActions(ATCTFolder,
         (
@@ -210,7 +211,8 @@ class ATTopic(ATCTFolder):
         # Enable topic syndication by default
         syn_tool = getToolByName(self, 'portal_syndication', None)
         if syn_tool is not None:
-            if syn_tool.isSiteSyndicationAllowed():
+            if (syn_tool.isSiteSyndicationAllowed() and
+                                    not syn_tool.isSyndicationAllowed(self)):
                 syn_tool.enableSyndication(self)
         return ret_val
 
@@ -339,7 +341,7 @@ class ATTopic(ATCTFolder):
     def listSortFields(self):
         """Return a list of available fields for sorting."""
         fields = [ field
-                    for field in self.listFields() 
+                    for field in self.listFields()
                     if self.validateAddCriterion(field[0], 'ATSortCriterion') ]
         return fields
 
@@ -461,8 +463,8 @@ class ATTopic(ATCTFolder):
         if max_items and b_size is None:
             b_size = int(max_items)
         else:
-            b_size = 20
-        if limit and max_items and self.hasSortCriterion():
+            b_size = b_size or 20
+        if not batch and limit and max_items and self.hasSortCriterion():
             # Sort limit helps Zope 2.6.1+ to do a faster query
             # sorting when sort is involved
             # See: http://zope.org/Members/Caseman/ZCatalog_for_2.6.1
@@ -567,9 +569,9 @@ class ATTopic(ATCTFolder):
 
     def HEAD(self, REQUEST, RESPONSE):
         """Retrieve resource information without a response body.
-        
-        An empty Topic returns 404 NotFound while a topic w/ a criterion returns
-        200 OK.
+
+        An empty Topic returns 404 NotFound while a topic w/ a
+        criterion returns 200 OK.
         """
         self.dav__init(REQUEST, RESPONSE)
         criteria = self.listCriteria()
